@@ -10,13 +10,21 @@ class DataRegistryApiService(object):
 
     def queryData(self, model, query, options):
 
-        fieldName = model["group"]
+        fieldPath = model["name"]
+
+        if "group" in model and model["group"] is not None:
+            fieldPath = model["group"]+"/"+fieldPath
+        if "namespace" in model and model["namespace"] is not None:
+            fieldPath = model["namespace"]+"/"+fieldPath
 
         filter = query["mongoQuery"] if query is not None else {}
 
 
         query_data = {
                 "filter": filter,
+                "models": [
+                    model
+                ]
             }
 
         headers = {
@@ -33,7 +41,7 @@ class DataRegistryApiService(object):
         if self.registry is not None and "endpoint" in self.registry:
 
             try:
-                data = requests.post(self.registry["endpoint"]+"/api/data/"+fieldName,
+                data = requests.post(self.registry["endpoint"]+"/api/data/"+fieldPath,
                                      json=query_data, headers=headers)
                 json_data = data.json()
 
