@@ -20,9 +20,9 @@ debug = debug
 registrar.worker = PipedashWorker()
 
 
-def connect(api_key="", secret_key=""):
+def connect(your_worker_name, api_key="", secret_key=""):
     log.info("Welcome to pipedash. We are connceting...")
-    return registrar.worker.connect(api_key, secret_key)
+    return registrar.worker.connect(your_worker_name, api_key, secret_key)
 
 
 def registerDrawable(component: Type[TDrawableComponent], name: str, description: str, imageUrl: str,
